pub struct BoxAllocator;Trait Implementations
Sourceimpl<'a, A> DocAllocator<'a, A> for BoxAllocatorwhere
A: 'a,
impl<'a, A> DocAllocator<'a, A> for BoxAllocatorwhere
A: 'a,
type Doc = BoxDoc<'a, A>
fn alloc(&'a self, doc: Doc<'a, Self::Doc, A>) -> Self::Doc
fn alloc_column_fn( &'a self, f: impl Fn(usize) -> Self::Doc + 'a, ) -> <Self::Doc as DocPtr<'a, A>>::ColumnFn
fn alloc_width_fn( &'a self, f: impl Fn(isize) -> Self::Doc + 'a, ) -> <Self::Doc as DocPtr<'a, A>>::WidthFn
fn alloc_cow(&'a self, doc: BuildDoc<'a, Self::Doc, A>) -> Self::Doc
Sourcefn nil(&'a self) -> DocBuilder<'a, Self, A>
fn nil(&'a self) -> DocBuilder<'a, Self, A>
Allocate an empty document.
Sourcefn fail(&'a self) -> DocBuilder<'a, Self, A>
fn fail(&'a self) -> DocBuilder<'a, Self, A>
Fails document rendering immediately. Read more
Sourcefn hardline(&'a self) -> DocBuilder<'a, Self, A>
fn hardline(&'a self) -> DocBuilder<'a, Self, A>
Allocate a single hardline.
fn space(&'a self) -> DocBuilder<'a, Self, A>
Sourcefn line(&'a self) -> DocBuilder<'a, Self, A>
fn line(&'a self) -> DocBuilder<'a, Self, A>
A line acts like a
\n but behaves like space if it is grouped on a single line.Sourcefn line_(&'a self) -> DocBuilder<'a, Self, A>
fn line_(&'a self) -> DocBuilder<'a, Self, A>
Sourcefn softline(&'a self) -> DocBuilder<'a, Self, A>
fn softline(&'a self) -> DocBuilder<'a, Self, A>
A
softline acts like space if the document fits the page, otherwise like lineSourcefn softline_(&'a self) -> DocBuilder<'a, Self, A>
fn softline_(&'a self) -> DocBuilder<'a, Self, A>
A
softline_ acts like nil if the document fits the page, otherwise like line_Sourcefn as_string<U: Display>(&'a self, data: U) -> DocBuilder<'a, Self, A>
fn as_string<U: Display>(&'a self, data: U) -> DocBuilder<'a, Self, A>
Allocate a document containing the text
t.to_string(). Read moreSourcefn text<U: Into<Cow<'a, str>>>(&'a self, data: U) -> DocBuilder<'a, Self, A>
fn text<U: Into<Cow<'a, str>>>(&'a self, data: U) -> DocBuilder<'a, Self, A>
Allocate a document containing the given text. Read more
Sourcefn concat<I>(&'a self, docs: I) -> DocBuilder<'a, Self, A>
fn concat<I>(&'a self, docs: I) -> DocBuilder<'a, Self, A>
Allocate a document concatenating the given documents.
Sourcefn intersperse<I, S>(&'a self, docs: I, separator: S) -> DocBuilder<'a, Self, A>
fn intersperse<I, S>(&'a self, docs: I, separator: S) -> DocBuilder<'a, Self, A>
Allocate a document that intersperses the given separator
S between the given documents
[A, B, C, ..., Z], yielding [A, S, B, S, C, S, ..., S, Z]. Read moreSourcefn column(
&'a self,
f: impl Fn(usize) -> Self::Doc + 'a,
) -> DocBuilder<'a, Self, A>
fn column( &'a self, f: impl Fn(usize) -> Self::Doc + 'a, ) -> DocBuilder<'a, Self, A>
Allocate a document that acts differently based on the position and page layout Read more
Sourceimpl<'a, A> Pretty<'a, BoxAllocator, A> for BoxDoc<'a, A>where
A: 'a,
impl<'a, A> Pretty<'a, BoxAllocator, A> for BoxDoc<'a, A>where
A: 'a,
Sourcefn pretty(self, allocator: &'a BoxAllocator) -> DocBuilder<'a, BoxAllocator, A>
fn pretty(self, allocator: &'a BoxAllocator) -> DocBuilder<'a, BoxAllocator, A>
Converts
self into a documentAuto Trait Implementations
impl Freeze for BoxAllocator
impl RefUnwindSafe for BoxAllocator
impl Send for BoxAllocator
impl Sync for BoxAllocator
impl Unpin for BoxAllocator
impl UnsafeUnpin for BoxAllocator
impl UnwindSafe for BoxAllocator